@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Licensed under the terms of the BSD 3-Clause
-# (see cdlclient/LICENSE for details)
+# Copyright (c) DataLab Platform Developers, BSD 3-Clause license, see LICENSE file.
 
 """
 DataLab Simple Client configuration module
@@ -12,8 +9,6 @@ This module handles `DataLab Simple Client` configuration.
 
 from __future__ import annotations
 
-import os.path as osp
-
 from guidata import configtools
 
 MOD_NAME = "cdlclient"
